@@ -1,6 +1,8 @@
 LRFN.plot <-
-function(M, xlim = NULL, ylim = NULL, lwd = NULL, lty = NULL, col = NULL, add = NULL, Left.fun = NULL, Right.fun = NULL)
+function(M, Left.fun = NULL, Right.fun = NULL, xlim = NULL, ylim = NULL, lwd = NULL, lty = NULL, col = NULL, add = NULL)
 {
+if ( length(col) == 0) {col=1}
+
 if ( messages(M) != 1 )  { return( messages(M) ) }
 
 m = M[1]
@@ -16,6 +18,7 @@ if ( M[4] == 0 ) { y = Left.fun((m-x)/m_l) * (x<=m) + Right.fun((x-m)/m_r) * (m<
 
 y = y * (0<=y & y<=1)
 par(new = add)
-return( plot(x, y, type = 'l', xlim = xlim, ylim = ylim, lwd = lwd, lty = lty, col = col, new = add) )
-  if (Left.fun == Right.fun+100 ) print(2) #Yek jomleye alaki choon CRAN majburet karde bud ke ...
+return( plot.default(x, y, type = 'l', xlim = xlim, ylim = ylim, lwd = lwd, lty = lty, col = col, new = add) )
+# if (Left.fun == Right.fun + 100 ) print(2) # Yek jomleye alaki choon CRAN majburet karde bud ke 
+# argument-haye Left.fun va Right.fun ra baraye tabe alaki tarif koni va az an-ha estefade koni
 }
